==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SkalaKryteriumOcenyKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class SkalaKryteriumOcenyKey extends GenericDPSObject {
    /**
     * SKALA_KRYTERIUM_OCENY.SKALA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long skalaId;

    /**
     * SKALA_KRYTERIUM_OCENY.KRYTERIUM_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kryteriumId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SKALA_KRYTERIUM_OCENY.SKALA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSkalaId() {
        return skalaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * SKALA_KRYTERIUM_OCENY.SKALA_ID
     *
     * @param skalaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSkalaId(Long skalaId) {
        this.skalaId = skalaId;
    }

    /**
     * @return SKALA_KRYTERIUM_OCENY.KRYTERIUM_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKryteriumId() {
        return kryteriumId;
    }

    /**
     * SKALA_KRYTERIUM_OCENY.KRYTERIUM_ID
     *
     * @param kryteriumId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKryteriumId(Long kryteriumId) {
        this.kryteriumId = kryteriumId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SkalaKryteriumOcenyKey other = (SkalaKryteriumOcenyKey) that;
        return (this.getSkalaId() == null ? other.getSkalaId() == null : this.getSkalaId().equals(other.getSkalaId()))
            && (this.getKryteriumId() == null ? other.getKryteriumId() == null : this.getKryteriumId().equals(other.getKryteriumId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSkalaId() == null) ? 0 : getSkalaId().hashCode());
        result = prime * result + ((getKryteriumId() == null) ? 0 : getKryteriumId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", skalaId=").append(skalaId);
        sb.append(", kryteriumId=").append(kryteriumId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SkalaKryteriumOcenyKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class SkalaKryteriumOcenyKey extends GenericDPSObject {
    /**
     * SKALA_KRYTERIUM_OCENY.SKALA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long skalaId;

    /**
     * SKALA_KRYTERIUM_OCENY.KRYTERIUM_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kryteriumId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SKALA_KRYTERIUM_OCENY.SKALA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSkalaId() {
        return skalaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:46
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * SKALA_KRYTERIUM_OCENY.SKALA_ID
     *
     * @param skalaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSkalaId(Long skalaId) {
        this.skalaId = skalaId;
    }

    /**
     * @return SKALA_KRYTERIUM_OCENY.KRYTERIUM_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKryteriumId() {
        return kryteriumId;
    }

    /**
     * SKALA_KRYTERIUM_OCENY.KRYTERIUM_ID
     *
     * @param kryteriumId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKryteriumId(Long kryteriumId) {
        this.kryteriumId = kryteriumId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SkalaKryteriumOcenyKey other = (SkalaKryteriumOcenyKey) that;
        return (this.getSkalaId() == null ? other.getSkalaId() == null : this.getSkalaId().equals(other.getSkalaId()))
            && (this.getKryteriumId() == null ? other.getKryteriumId() == null : this.getKryteriumId().equals(other.getKryteriumId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSkalaId() == null) ? 0 : getSkalaId().hashCode());
        result = prime * result + ((getKryteriumId() == null) ? 0 : getKryteriumId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", skalaId=").append(skalaId);
        sb.append(", kryteriumId=").append(kryteriumId);
        sb.append("]");
        return sb.toString();
    }
}
